<?php

/**
 * @file
 * REVE Chat is powerful and intuitive real-time customer engagement software.
 */

/**
 * Implements hook_form().
 */
function revechat_admin_settings_form($node, &$form_state) {
    $module_dir = drupal_get_path('module', 'revechat');
    drupal_add_css($module_dir . '/admin/css/revechat.css');
    drupal_add_js($module_dir . '/admin/js/revechat_admin.js');

    $form = array();

    if (revechat_is_installed()) {
        $form['revechat_success_message'] = array(
            '#markup' => '<div class="box">
                              <h3>' . t('REVE Chat has been installed.') . '</h3>'.
                '<p>'.t('Sign in to REVE Chat Dashboard and start chatting with your customers.').'</p>'.
                '<p><a style="background: #f08300; color: #ffffff; padding:10px;" href="https://dashboard.revechat.com" class="dashboard-btn" target="_blank">Go to Dashboard</a></p>'
                .'</div>',
        );

        $form['actions']['#type'] = 'actions';
        $form['actions']['submit'] = array(
            '#type' => 'submit',
            '#prefix' => '<div class="remove_btn"><p><small>Something went wrong?</small>',
            '#value' => t('Disconnect'),
            '#suffix' => '</p></div>',
        );

        return $form;
    }
    else {
        // New account / Already have a license forms.
        $form['choose_form'] = array(
            '#type' => 'item',
            '#markup' => '<h3>Do you already have a REVE Chat account?</h3>
      <ul id="revechat_choose_form">
        <li>
            <input type="radio" name="revechat_choose_form" id="has_revechat_account" checked="checked"> 
            <label for="has_revechat_account">Yes, I already have a REVE Chat account</label>
            </li>
        <li>
            <input type="radio" name="revechat_choose_form" id="new_revechat_account"> 
            <label for="new_revechat_account">No, I want to create one</label>
        </li>
            </ul>',
        );

        $form['general'] = array(
            '#type' => 'fieldset',
            '#collapsible' => FALSE,
            '#prefix' => '<div id="revechat_already_have"><h3>Account Details</h3>',
            '#suffix' => '</div>',
        );
        $form['general']['ajax_message'] = array(
            '#type' => 'item',
            '#markup' => '<p class="ajax_message"></p>',
        );
        $form['general']['revechat_account_email'] = array(
            '#type' => 'textfield',
            '#title' => t('REVE Chat Login Email'),
            '#default_value' => '',
            '#required' => FALSE,
        );
        $form['general']['revechat_aid'] = array(
            '#title' => t('Account ID'),
            '#description' => t('Account ID of Reve Chat'),
            '#type' => 'hidden',
            '#value' => 0,
        );

        // New account form.
        $form['new_revechat_account'] = array(
            '#type' => 'fieldset',
            '#collapsible' => FALSE,
            '#prefix' => '<div id="revechat_new_account"><h3>Create a new REVE Chat account</h3>',
            '#suffix' => '</div>',
        );
        $form['new_revechat_account']['ajax_message'] = array(
            '#type' => 'item',
            '#markup' => '<p class="ajax_message"></p>',
        );
        $form['new_revechat_account']['firstname'] = array(
            '#type' => 'textfield',
            '#title' => t('First Name'),
            '#required' => FALSE,
        );
        $form['new_revechat_account']['lastname'] = array(
            '#type' => 'textfield',
            '#title' => t('Last Name'),
            '#required' => FALSE,
        );
        $form['new_revechat_account']['email'] = array(
            '#type' => 'textfield',
            '#title' => t('Email address'),
            '#required' => FALSE,
        );
        $form['new_revechat_account']['accountpassword'] = array(
            '#type' => 'password',
            '#title' => 'Password',
            '#required' => FALSE,
        );

        $form['new_revechat_account']['retypepassword'] = array(
            '#type' => 'password',
            '#title' => 'Password',
            '#required' => FALSE,
        );

        $form['actions']['#type'] = 'actions';
        $form['actions']['submit'] = array(
            '#type' => 'submit',
            '#value' => t('Save'),
        );
        return $form;
    }
}

/**
 * Submit callback for license installation form.
 */
function revechat_admin_settings_form_submit($form, &$form_state) {
    if ($form_state['values']['op'] === t('Disconnect')) {
        // Forget license if the "Reset" button was clicked.
        variable_del('revechat_aid');
    }
    else {
        // Save the license that was returned by the admin JavaScript.
        variable_set('revechat_aid', $form_state['input']['revechat_aid']);
    }
}
